@@ -48,7 +48,6 @@ int semanage_set_root(const char *root)
 	return 0;
 }
 
-hidden_def(semanage_set_root);
 
 const char * semanage_root(void)
 {
@@ -58,6 +57,7 @@ const char * semanage_root(void)
 	return private_semanage_root;
 }
 
+
 semanage_handle_t *semanage_handle_create(void)
 {
 	semanage_handle_t *sh = NULL;
@@ -277,7 +277,7 @@ void semanage_select_store(semanage_handle_t * sh, char *storename,
 	assert(sh != NULL);
 
 	/* This just sets the storename to what the user requests, no 
-	   verification of existance will be done until connect */
+	   verification of existence will be done until connect */
 	free(sh->conf->store_path);
 	sh->conf->store_path = strdup(storename);
 	assert(sh->conf->store_path); /* no way to return failure */
@@ -362,7 +362,6 @@ int semanage_access_check(semanage_handle_t * sh)
 	return -1;		/* unreachable */
 }
 
-hidden_def(semanage_access_check)
 
 int semanage_disconnect(semanage_handle_t * sh)
 {
@@ -392,7 +391,6 @@ void semanage_handle_destroy(semanage_handle_t * sh)
 	free(sh);
 }
 
-hidden_def(semanage_handle_destroy)
 
 /********************* public transaction functions *********************/
 int semanage_begin_transaction(semanage_handle_t * sh)
@@ -414,7 +412,6 @@ int semanage_begin_transaction(semanage_handle_t * sh)
 	return 0;
 }
 
-hidden_def(semanage_begin_transaction)
 
 int semanage_commit(semanage_handle_t * sh)
 {
